<img src="https://github.com/OasisLMF/Workshop2019/raw/master/images/oasis-lmf-colour.png" width="250"/>



# Oasis Workshop 2022

## Quick start 

1. Download and install the **jupyterlab-desktop** application from its GitHub page 
    https://github.com/jupyterlab/jupyterlab-desktop/releases


2. Once installed, select the `open from URL` option. 

<img src="https://github.com/OasisLMF/Workshop2022/blob/main/images/load_notebook.png?raw=true" alt="Oasis LMF logo" width="600" align="center"/><br>

Copy in the raw Github URLs to load each exercise.

* **Exercise 1** - https://raw.githubusercontent.com/OasisLMF/Workshop2022/main/1_overview.ipynb
* **Exercise 2** - https://raw.githubusercontent.com/OasisLMF/Workshop2022/main/2_installing-models.ipynb
* **Exercise 3** - https://raw.githubusercontent.com/OasisLMF/Workshop2022/main/3_autoscalling.ipynb
* **Exercise 4** - https://raw.githubusercontent.com/OasisLMF/Workshop2022/main/4_user-access-management.ipynb
